# -*- coding: utf-8 -*-

import pygame

from OpenGL.GL import *

import world, gui, config
from pyeuclid.euclid import Vector3
from questmanager import set_quest

class MessageEvent (object):
	color = (128, 128, 128)

	def __init__(self, text):
		self.text = text
	
	def action(self):
		gui.messenger.add_message(gui.Message(self.text, color=self.color))

class ApologyEvent (MessageEvent):
	color = (192, 64, 64)

class Plexus (world.Trigger):
	color = (.7, .7, 0)
	z_offset = 250
	speed = 50.

	def __init__(self, pos, size, height, callback):
		world.Trigger.__init__(self, pos, size, height)
		self.callback = callback
	
	def action(self, flyer):
		self.callback(self)


class Quest (object):
	def __init__(self):
		self.time = self.last_event = 0.
		self.timers = []
		self.triggers = {}

	def think(self):
		self.time += 0.01

		for t, ev in self.timers:
			if self.last_event < t < self.time:
				ev.action()
				self.last_event = t

	def populate(self, area):
		triggers = self.triggers.get((area.x, area.y), [])
		for t in triggers:
			area.triggers.append(t)

class Intro (Quest):
	def __init__(self):
		Quest.__init__(self)

		self.timers = [
			(0.5, MessageEvent('When you wake up...')),
			(1.5, MessageEvent('you find yourself standing on a gigantic feather')),
			(1.7, MessageEvent('amidst howling wind, falling down from the skies.')),
			(4.0, MessageEvent('Use arrow keys to control the feather.')),
			(4.2, MessageEvent('Use red upwards air draughts to gain speed and altitude.')),
			(4.4, MessageEvent('Avoid blue downdraughts.')),
			(10., MessageEvent('A distant thought reaches you:')),
			(10.2, MessageEvent(u'«Find a geomagical plexus, it will help us communicate.»')),
		]

		self.triggers = {
			(-1, 0): [
				Plexus(Vector3(-2000, 2000, 0), 150, 3000, self.advance)
			]
		}

	
	def advance(self, plex):
		plex.disabled = True
		set_quest(Story1())


class Story1 (Quest):
	def __init__(self):
		Quest.__init__(self)

		self.timers = [
			(0.2, MessageEvent(u'«Great job.»')),
			(0.6, MessageEvent(u'«You have replenished your magic reserves,')),
			(0.8, MessageEvent(u'so now we will be able to communicate easily.»')),
			(1.8, MessageEvent(u'«You must have a lot of questions, but that must wait.»')),
			(2.4, MessageEvent(u'«First of all, you must master your feather,')),
			(2.6, MessageEvent(u'for it will be vital for your survival.»')),
			(3.0, MessageEvent(u'«Practice flying around on your feather,')),
			(3.2, MessageEvent(u'and, please, stay alive.»')),
			(3.8, MessageEvent(u'«Good luck!»')),

			(20., ApologyEvent(u'Unfortunately, this is all of a game for now.')),
			(21., ApologyEvent(u'Stay tuned for Pyggy Awards.')),
			(21.2, ApologyEvent(u'Thank you for playing.'))
		]


